@@ -9,10 +9,12 @@ import jsii.compat
 import publication
 
 import aws_cdk.aws_events
+import aws_cdk.aws_events_targets
 import aws_cdk.aws_lambda
 import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 import aws_cdk.core
+import constructs
 __all__ = []
 
 publication.publish()
